# [Office UI Fabric React FAQ](http://dev.office.com/fabric)

## *Q. What is Office UI Fabric React?*

Fabric React is a responsive, mobile-first, open-source collection of robust components designed to make it quick and simple for you to create web experiences using the `Office Design Language`.

## *Q. Who uses Office UI Fabric React?*

React components from Office UI Fabric React are used by many teams accross O365 and Microsoft for building their experiences. Some examples are SharePoint, OneDrive, Outlook, VisualStudio team services, ...

These components are also used by third party developers building extensiblity components using the SharePoint Framework.

## *Q. How do I get started with Office UI Fabric React?*

Start with our [README](./README.md) document.

To create your first app using Office UI Fabric React read the [Sample App](./ghdocs/OnBoarding/SampleApp.md) document.

## *Q. Where is the official website located?*

https://developer.microsoft.com/fabric

http://dev.office.com/fabric

## *Q. I am seeing a bug. Where can I open an issue?*

Please open all issues at our [GitHub issues](https://github.com/OfficeDev/office-ui-fabric-react/issues) location.

Things to remember while opening an issue

* Please fill out as many details as you can.
* We **highly encourage** you to submit PRs for issues.



```
  ----------------------------------------------------------------------------------------------

  ### Bug Report

  - __Package version(s)__: (fill this out)
  - __Browser and OS versions__: (fill this out if relevant)

  #### Priorities and help requested (not applicable if asking question):

  Are you willing to submit a PR to fix? (Yes, No)

  Requested priority: (Blocking, High, Normal, Low)

  Products/sites affected: (if applicable)

  #### Describe the issue:

  <!-- fill this out -->

  #### Actual behavior:

  <!-- fill this out -->

  #### Expected behavior:

  <!-- fill this out -->

  ### If applicable, please provide a codepen repro:

  <!-- See http://codepen.io/dzearing/pens/public/?grid_type=list for a variety of examples -->

  ----------------------------------------------------------------------------------------------
```


## *Q. Can I contribute to Office UI Fabric React?*

Office UI Fabric React is an open-source distributed project. Lots of developers from inside and outside Microsoft contribute to this project. We highly encourage contributions. There is a core team that works hard to stay on top of the issues and pull requests.

## *Q. Why should I contribute?*

Office UI Fabric React is an open-source distributed project. If you are building a new app inside O365 or Microsoft, this project will potentially save you lots of time, resources and headaches. We encourage all developers who use Fabric React to return a small amount to the community. If you notice bugs, we encourage you to not only open an issue on it but also help fix it. If you have a component that you believe others should use, feel motivated and encouraged to contribute that component back to the community. Sharing is caring. Many developers contribute outside their primary job responsibilities. Additionally, there is plenty to learn. We use a lot of cutting edge best practices used in the industry. Learning those can help you in your career.

## *Q. How do I communicate with a Fabric React core team member?*

We have a very active community both outside and inside Microsoft. Please use the Microsoft [Teams channel](https://teams.microsoft.com/l/channel/19%3a73a5dbc26c9a4d8d91264611995bbdbb%40thread.skype/Fabric%2520Design?groupId=ffe264f2-14d0-48b5-9384-64f808b81294&tenantId=72f988bf-86f1-41af-91ab-2d7cd011db47) for communication from within Microsoft. And a [GitHub issue](https://github.com/OfficeDev/office-ui-fabric-react/issues) from outside Microsoft. We triage these issues at least once a week.

## *Q. How do I contribute to Office UI Fabric React?*

Start by reading our [Contributing](./ghdocs/Contributing/Contributing.md) document. Please point out any missing or incorrect details.

## *Q. Can I become a part of the Fabric core team?*

Yes, you totally can. You will need to help out with reviewing pull requests and triaging and fixing issues. For now, only Microsoft employees can be a part of the core team. We are looking into changing that policy to allow non-Microsoft folks to be a part of the core team.

## *Q. My pull request has been hanging for a long time. What do I do?*

We are very proactive and work hard to keep the outstanding pull request count low. But if your pull request is non-trivial and stuck for a long time, please feel free to tag the pull request that it has been hanging for long and you need help.

## *Q. Where do I read about specific best practices?*

Please refer to the following documents.

[**Contributing fixes and new components**](./ghdocs/Contributing/Contributing.md)

[**Accessibility**](./ghdocs/BestPractices/Accessibility.md)

[**Component Design**](./ghdocs/BestPractices/ComponentDesign.md)

[**Styling**](./ghdocs/BestPractices/Styling.md)

[**Theming**](./ghdocs/BestPractices/Theming.md)

[**Testing**](./ghdocs/BestPractices/Testing.md)

[**Advanced**](./ghdocs/BestPractices/Advanced.md)

[**Browse Support**](./ghdocs/Testing/BrowserSupport.md)

## *Q. When and how does the issue Triage work?*

The Fabric React core team works hard to stay on top of the open issues. We triage issues at least once a week. Due to an increased volume in the number of issues, we have been triaging more often. Once the issue count is under control, we may go back to the once a week rythm.

### Following issues will qualify as high priority

We try to fix high priority bugs ASAP.

* Is this issue blocking the consumer?
* Is this a regression? If yes, how and when did it get in?* Is this a very serious bug?

Other bugs will qualify as Normal or lower priority and will get fixed as a part of the normal release cadence.

From time to time we do plan to close issues that are very old and have no activity.

## *Q. Why do I get the `stale[bot]` messages? Why is my issue marked as stale?*

We have recently configured the [GitHub stale BOT](https://github.com/probot/stale) as a scaling mechanism for us because there have been many issues that simply don't repro anymore or have been fixed without the triaging group seeing them/making the connection between fix->issue. The bot encourages issue openers to follow-up if it's still an active issue, and if it’s not, let’s close them.

### What issues will be automatically resolved?

We plan to resolve all issues before `October 1, 2017` automatically. For issues after that date, we are aggressively triaging them and creating a plan to get them fixed ASAP.

### How does Stale-bot work?

The bot sniffs out 'stale' issues in the repository based on date and activity. If an issue has not had any activity (comments, labels, title change, assignment, etc.) in certain number of (configurable) days, the Stale-bot will add the label 'no-recent-activity', and comment on the issue that it will be closed in 14-days if no further activity occurs. If no activity happens on this issue in the next two weeks, Stale-bot will automatically close the issue. This is intended to provide a reasonable level of cleanup so that valid issues don't get lost in the ocean of no longer relevant issues.

### But my issue is relevant, it’s just a long discussion! What can I do?

Stale-bot is versatile and has exemption labels, projects, and milestones. As of right now any issues marked 'Priority 0', 'Priority 1', 'Needs: discussion', and 'Needs: revisit' will never be marked stale.

We ask everyone to not abuse these. This cleanup is for better organization of the Fabric React project with the goal to increase visibility and response time on bugs and feature requests and organizing the issues is key to this endeavor. If there is a more semantic label to express, why your issue needs to stick around for multiple months tag the issue as such and we will triage it appropriately.